palsr-package: palsr: Projected Actor Locations for Spatial Interaction...

palsr-packageR Documentation

palsr: Projected Actor Locations for Spatial Interaction Modeling

Description

Implements the Projected Actor Locations (PALS) method for spatial modeling of dyadic interactions between geographically mobile actors, as described in Kim, Liu and Desmarais (2023) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1017/psrm.2022.6")}. PALS applies exponential-smoothing weights to the spatiotemporal histories of a focal actor and its interaction partners ("alters") to project the location of future interactions. The package provides projection, maximum-similarity parameter estimation by minimizing great-circle (Haversine) prediction error, nonparametric bootstrap with multiple-imputation (Rubin's Rules) pooling, dyadic distance covariate construction, visualization, and a simulated example dataset of subnational conflict.

Author(s)

Maintainer: Bruce A. Desmarais bruce.desmarais@gmail.com

Authors:

See Also

Useful links:


palsr documentation built on July 1, 2026, 5:07 p.m.