| palsr-package | R Documentation |
Implements the Projected Actor Locations (PALS) method for spatial modeling of dyadic interactions between geographically mobile actors, as described in Kim, Liu and Desmarais (2023) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1017/psrm.2022.6")}. PALS applies exponential-smoothing weights to the spatiotemporal histories of a focal actor and its interaction partners ("alters") to project the location of future interactions. The package provides projection, maximum-similarity parameter estimation by minimizing great-circle (Haversine) prediction error, nonparametric bootstrap with multiple-imputation (Rubin's Rules) pooling, dyadic distance covariate construction, visualization, and a simulated example dataset of subnational conflict.
Maintainer: Bruce A. Desmarais bruce.desmarais@gmail.com
Authors:
Bruce A. Desmarais bruce.desmarais@gmail.com
Sangyeon Kim
Howard Liu
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.